--- old/usr/src/Makefile.master	Wed Oct  1 18:40:28 2014
+++ new/usr/src/Makefile.master	Wed Oct  1 18:40:28 2014
@@ -23,6 +23,7 @@
 # Copyright (c) 1989, 2010, Oracle and/or its affiliates. All rights reserved.
 # Copyright (c) 2012 by Delphix. All rights reserved.
 # Copyright 2014 Garrett D'Amore <garrett@damore.org>
+# Copyright 2014 Gary Mills
 #
 
 #
@@ -386,6 +387,9 @@
 # Unfortunately, this option can misfire very easily and unfixably.
 CERRWARN +=	-_gcc=-Wno-array-bounds
 
+# Suppress it: this warning generates many false alarms
+CERRWARN +=	-_gcc=-Wno-uninitialized
+
 # DEBUG v. -nd make for frequent unused variables, empty conditions, etc. in
 # -nd builds
 $(RELEASE_BUILD)CERRWARN += -_gcc=-Wno-unused
@@ -414,11 +418,14 @@
 i386_ASFLAGS=	$(i386_AS_XARCH)
 amd64_ASFLAGS=	$(amd64_AS_XARCH)
 
+# Adjustments to specified optimization level
+ADJUST_COPT=		-_gcc=-fno-strict-aliasing -_gcc=-fno-tree-vrp
+
 #
-sparc_COPTFLAG=		-xO3
-sparcv9_COPTFLAG=	-xO3
-i386_COPTFLAG=		-O
-amd64_COPTFLAG=		-xO3
+sparc_COPTFLAG=		$(ADJUST_COPT) -xO3
+sparcv9_COPTFLAG=	$(ADJUST_COPT) -xO3
+i386_COPTFLAG=		$(ADJUST_COPT) -O
+amd64_COPTFLAG=		$(ADJUST_COPT) -xO3
 
 COPTFLAG= $($(MACH)_COPTFLAG)
 COPTFLAG64= $($(MACH64)_COPTFLAG)
--- old/usr/src/tools/cw/cw.c	Wed Oct  1 18:40:29 2014
+++ new/usr/src/tools/cw/cw.c	Wed Oct  1 18:40:29 2014
@@ -20,6 +20,8 @@
  */
 
 /*
+ * Copyright 2014 Gary Mills
+ *
  * Copyright 2010 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
@@ -33,7 +35,7 @@
  */
 
 /* If you modify this file, you must increment CW_VERSION */
-#define	CW_VERSION	"1.29"
+#define	CW_VERSION	"1.30"
 
 /*
  * -#		Verbose mode
@@ -534,16 +536,6 @@
 	newae(h, "-Wextra");
 }
 
-static void
-optim_disable(struct aelist *h, int level)
-{
-	if (level >= 2) {
-		newae(h, "-fno-strict-aliasing");
-		newae(h, "-fno-unit-at-a-time");
-		newae(h, "-fno-optimize-sibling-calls");
-	}
-}
-
 /* ARGSUSED */
 static void
 Xamode(struct aelist *h)
@@ -1305,18 +1297,6 @@
 					level = atoi(arg + 3);
 					if (level > 5)
 						error(arg);
-					if (level >= 2) {
-						/*
-						 * For gcc-3.4.x at -O2 we
-						 * need to disable optimizations
-						 * that break ON.
-						 */
-						optim_disable(ctx->i_ae, level);
-						/*
-						 * limit -xO3 to -O2 as well.
-						 */
-						level = 2;
-					}
 					(void) snprintf(s, len, "-O%d", level);
 					newae(ctx->i_ae, s);
 					free(s);
--- old/usr/src/uts/intel/Makefile.intel	Wed Oct  1 18:40:29 2014
+++ new/usr/src/uts/intel/Makefile.intel	Wed Oct  1 18:40:29 2014
@@ -21,6 +21,7 @@
 # Copyright (c) 2005, 2010, Oracle and/or its affiliates. All rights reserved.
 # Copyright (c) 2012 Nexenta Systems, Inc. All rights reserved.
 # Copyright (c) 2013 Andrew Stormont.  All rights reserved.
+# Copyright 2014 Gary Mills
 
 #
 #	This makefile contains the common definitions for all intel
@@ -116,8 +117,8 @@
 CFLAGS_XARCH_64		= $(amd64_CFLAGS)
 CFLAGS_XARCH		= $(CFLAGS_XARCH_$(CLASS))
 
-COPTFLAG_32		= $(COPTFLAG)
-COPTFLAG_64		= $(COPTFLAG64)
+COPTFLAG_32		= -_gcc=-fno-toplevel-reorder $(COPTFLAG)
+COPTFLAG_64		= -_gcc=-fno-toplevel-reorder $(COPTFLAG64)
 COPTIMIZE		= $(COPTFLAG_$(CLASS))
 
 CFLAGS			= $(CFLAGS_XARCH)
